@@ -4,13 +4,13 @@ from stef.runner import Runner
 from stef.logger import Logger
 
 class BashRunner(Runner):
-    def __init__(self, solution_base_dir, binary_name,  skip_setup=True):
+    def __init__(self, solution_base_dir, binary_name, skip_setup=True):
         super().__init__(solution_base_dir, binary_name, skip_setup=skip_setup)
 
     # guarentees some prerequirements 
     # can be overriden, should return 1 if the setup failed
-    def prerequierments(self):
-        self.prerequierments_run = True
+    def prerequirements(self):
+        self.prerequirements_run = True
         return True
 
     def run_command(self, command, workdir=None):
@@ -27,7 +27,10 @@ class BashRunner(Runner):
         #output = subprocess.check_output(["bash", path + binary_to_test, command_line_arg_str]).trim()
 
         proc = subprocess.Popen(["bash", self.get_bin_path()] + command_line_arg,
-                                stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=self.solution_base_dir)
+                                stdin=subprocess.PIPE,
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE,
+                                cwd=self.solution_base_dir)
         outs, errs = proc.communicate(inp.encode('utf-8'))
         output = outs.decode("utf-8")
         stderr = errs.decode("utf-8")
